@@ -14,13 +14,13 @@
 
 """Exceptions for the Brick library."""
 
-from oslo_concurrency import processutils as putils
-import six
 import traceback
 
-from os_brick.i18n import _
+from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
 
+from os_brick.i18n import _
+
 
 LOG = logging.getLogger(__name__)
 
@@ -67,9 +67,6 @@ class BrickException(Exception):
         self.msg = message
         super(BrickException, self).__init__(message)
 
-    def __unicode__(self):
-        return six.text_type(self.msg)
-
 
 class NotFound(BrickException):
     message = _("Resource could not be found.")
@@ -200,7 +197,7 @@ class ExceptionChainer(BrickException):
                                    for i, t in enumerate(tracebacks))
         return self._repr
 
-    __str__ = __unicode__ = __repr__
+    __str__ = __repr__
 
     def __nonzero__(self):
         # We want to be able to do boolean checks on the exception
