@@ -13,13 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
-
 import os
 import time
 
-import six
-
 from oslo_log import log as logging
 from oslo_utils import importutils
 
@@ -193,7 +189,7 @@ class StorPoolConnector(base.BaseLinuxConnector):
         (out, _err) = self._execute('blockdev', '--getsize64',
                                     device, run_as_root=True,
                                     root_helper=self._root_helper)
-        var = six.text_type(out).strip()
+        var = str(out).strip()
         if var.isnumeric():
             return int(var)
         else:
